ImageLoadResult class
Result wrapper for asynchronous image loading.
Constructors
- ImageLoadResult({Image? image, Object? error, StackTrace? stackTrace})
-
const
Properties
- error → Object?
-
Captured error when loading fails.
final
- hasError → bool
-
Returns
truewhen error is present.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- image → Image?
-
Decoded image when loading succeeds.
final
- isSuccess → bool
-
Returns
truewhen image is present.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace captured for error.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited