ShaderConversionIssue class

Conversion warning or error emitted while transforming source GLSL.

Constructors

ShaderConversionIssue({required String message, bool isError = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isError bool
Whether this issue should fail conversion output.
final
message String
Human-readable issue description.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited