ShaderFloatProperty class

Float uniform property descriptor generated by ShaderConverter.

Constructors

ShaderFloatProperty({required double defaultValue, required double min, required double max})
const

Properties

defaultValue double
Suggested starting value.
final
hashCode int
The hash code for this object.
no setterinherited
max double
Maximum allowed value.
final
min double
Minimum allowed value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this descriptor as JSON-compatible map data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited