ShaderProgramCache class

Cache for compiled ui.FragmentProgram instances keyed by asset path.

Constructors

ShaderProgramCache()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() → void
Clears all cached programs.
load(String shaderPath) Future<FragmentProgram>
Loads and caches a fragment program for shaderPath.