CommonUniformNames class
Shared built-in uniform names commonly written by ShaderUniformsBuilder.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
all
→ const List<
String> - Full set of shared built-in names.
- cameraOffsetX → const String
- Camera X offset for gesture-driven shaders.
- cameraOffsetY → const String
- Camera Y offset for gesture-driven shaders.
- iMouseX → const String
- Pointer X position.
- iMouseY → const String
- Pointer Y position.
- iResolutionX → const String
- Logical output width in pixels.
- iResolutionY → const String
- Logical output height in pixels.
- iTime → const String
- Elapsed shader time in seconds.
- viewportScale → const String
- Camera zoom scalar for gesture-driven shaders.