ShaderUniforms class
Runtime values passed to a fragment shader for one paint cycle.
Use floats for numeric uniforms and sampler2Ds for texture uniforms. version is used by painters to detect uniform changes efficiently.
Constructors
Properties
-
floats
→ Map<
String, double> -
Numeric uniform values keyed by uniform name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sampler2Ds
→ Map<
String, Image> -
Texture uniforms keyed by uniform name.
final
- version → int
-
Monotonic change version used by repaint heuristics.
final
Methods
-
copyWith(
{Map< String, double> ? floats, Map<String, Image> ? sampler2Ds, int? version}) → ShaderUniforms - Returns a copy with selective overrides.
-
dispose(
) → void - Disposes all texture images contained in sampler2Ds.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited